@@ -1,6 +1,6 @@
 ggadd_density <- function(p, resmca, var, cat=levels(var)[1], axes=c(1,2),
                           density="contour", col.contour="darkred", pal.area="viridis", alpha.area=0.2,
-                          ellipse=FALSE, col.ellipse="black"){
+                          ellipse=FALSE){
 
   type <- attr(resmca,'class')[1]
   
@@ -20,8 +20,7 @@ ggadd_density <- function(p, resmca, var, cat=levels(var)[1], axes=c(1,2),
                                ggplot2::scale_fill_continuous(type="viridis", option=pal.area) +
                                ggplot2::theme(legend.position="none")
     
-  #if(ellipse==TRUE) p <- p + ggplot2::stat_ellipse(data=df, ggplot2::aes(x=.data$dim.1, y=.data$dim.2), colour=col.ellipse, level=0.86, type='norm', size=.2)
-  if(ellipse==TRUE) p <- ggadd_kellipses(p=p, resmca=resmca, var=var, sel=which(levels(var)==cat), axes=axes, col=col.ellipse, size=0.3, label=FALSE, points=FALSE, legend="none")
+  if(ellipse==TRUE) p <- ggadd_kellipses(p=p, resmca=resmca, var=var, sel=which(levels(var)==cat), axes=axes, size=0.3, label=FALSE, points=FALSE, legend="none")
   
   return(p)
 }
\ No newline at end of file
